@@ -10,7 +10,6 @@ from dataservice.exceptions import DataServiceException, RetryableException
 from dataservice.logs import setup_logging
 from dataservice.models import FailedRequest, Request, Response
 from dataservice.service import DataService
-import importlib.metadata
 
 __all__ = [
     "BaseDataItem",
@@ -28,5 +27,3 @@ __all__ = [
     "RetryConfig",
     "setup_logging",
 ]
-
-__version__ = importlib.metadata.version("python-dataservice")
